# Enable HMM filter

One can remove `--nohmm` in the command to enable HMM filter. However, HMM filter may also filter some important structures. One should read the original ReacNetGenerator paper{cite:p}`Zeng_PhysChemChemPhys_2020_v22_p683` and carefully adjust HMM parameters.

HMM filter should not be used to generate the special result by time step.